/*
	Chapter 6
	Figure 6.10
	Extrapolate baseline survival function from 10 to 30 years.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit MFP model, predict index and center it around its mean
xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, scale(odds) df(2)
predict xb, xbnobaseline
sum xb
replace xb = xb - r(mean)
xi: stpm2 xb, scale(odds) df(2)
predict s0, survival zeros

// Predict at times 0(1)30
drop s0
range timev 0 30 31
predict s0, survival zeros timevar(timev)
replace s0 = 1 if timev == 0

// Get Kaplan-Meier up to 20 years
stset rf, id(pid) failure(rfi==1) scale(12)
sts gen s_kap = s
twoway (line s_kap _t, c(J) sort) (line s0 timev, lpattern(-) sort) ///
 , xline(10) yla(0(0.25)1, angle(h) format(%4.2f)) ///
 xtitle("Years since surgery") ytitle("Survival probability") ///
 legend(label(1 "Kaplan-Meier, extended") label(2 "PO(2) model, extrapolated") ///
 ring(0) pos(1) col(1))
set more on
