/*
	Chapter 6
	Figure 6.11
	Extrapolate survival function from 10 to 30 years with df 1/4,
	scales hazard, odds and normal.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

range timev 0 30 31

// 3 scales of RP models, df = 1, 2, 3, 4; bknots default; extrapolate to 30 years
forvalues j = 1 / 4 {
	foreach scale in hazard odds normal {
		quietly stpm2, df(`j') scale(`scale')
		predict s_`scale'_`j', survival timevar(timev)
		quietly replace s_`scale'_`j' = 1 if timev == 0
	}
}

// Get Kaplan-Meier up to 20 years
stset rf, id(pid) failure(rfi==1) scale(12)
sts gen s_kap = s

// Plot for each df in turn
forvalues j = 1 / 4 {
	if `j' == 1 {
		local legend legend(label(1 "Kaplan-Meier") label(2 "Weibull")
		local legend `legend' label(3 "Log-logistic") label(4 "Lognormal")
		local legend `legend' ring(0) pos(1) col(1))
	}
	else {
		local legend legend(label(1 "Kaplan-Meier") label(2 "PH(`j')")
		local legend `legend' label(3 "PO(`j')") label(4 "Probit(`j')")
		local legend `legend' ring(0) pos(1) col(1))
	}
	twoway (line s_kap _t, c(J) sort) ///
	 (line s_hazard_`j' s_odds_`j' s_normal_`j' timev, ///
	 lpattern(- _ -.) lcolor(gs10 ..) sort) ///
	 , xline(10) ylabel(0(0.25)1, angle(h) format(%4.2f)) ///
	 xtitle("") ytitle("") `legend' name(g`j', replace)
}

graph combine g1 g2 g3 g4, b2title("Years since surgery") ///
l1title("Survival probability") imargin(tiny)
set more on
