/*
	Chapter 6
	Figure 6.13
	Impute censored survival times and plot against x*beta.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit MFP model and predict prognostic index (excluding the spline terms)
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)
predict xb, xbnobaseline

// Impute censored times to event under PCO(2) model
stsurvimpute xb, seed(111) gen(timp) scale(odds) df(2)

// Refit model to prognostic index and estimate survival probabilities
quietly stpm2 xb, scale(odds) df(2)
local obs +
local imp o
label define d 0 "`imp'" 1 "`obs'"
label values _d d

// Get cutpoints on predicted survival time for plotting
quietly centile xb, centile(10 25 75 90)
forvalues j = 1 / 4 {
	local cut`j' = r(c_`j')
}
gen lnt = ln(timp)
quietly regress lnt xb
predict lntf
local logten = ln(10)
gen lnt0 = lnt if _d == 0
gen lnt1 = lnt if _d == 1
scatter lnt0 lnt1 xb, ms(oh +) mcolor(gs9 gs6) msize(*.75 ..) ///
 yline(`logten') ylabel(, angle(horizontal)) ///
 xline(`cut1' `cut2' `cut3' `cut4', lpattern(dash) lwidth(thin)) ///
 xtitle("Prognostic index") ytitle("Log years since surgery") ///
 note("`imp' = imputed, `obs' = observed") legend(off)
set more on
