/*
	Chapter 6
	Figure 6.4
	Plot survival probabilities at different centiles of x*beta.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit MFP model and predict prognostic index
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)
predict xb, xbnobaseline // excludes the spline terms

// Refit model to xb and estimate survival probabilities
quietly stpm2 xb, scale(odds) df(2)

// Compute survival curves at 10th,...,90th centiles of index
gen timevar = _n / 10 in 1 / 100
forvalues j = 1 / 9 {
	local centile = `j' * 10
	quietly centile xb, centile(`centile')
	local cxb = r(c_1)
	predict s`j', at (xb `cxb') survival timevar(timevar)
}
line s1 s2 s3 s4 s5 s6 s7 s8 s9 timevar, sort legend(off) lpattern(l ..) ///
 lwidth(medthin medthin medthin medthin thick medthin  ..) ///
 xtitle("Years since surgery") ytitle("S(t)") ///
 ylabel(0(0.2)1, angle(h) format(%4.1f)) yscale(r(0 1)) ///
 text(0.78 8 "10th centile", place(e)) text(0.1 8 "90th centile", place(e))
set more on
