/*
	Chapter 6
	Figure 6.7
	Difference in survival functions, adjusted and unadjusted.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Adjust to medians of continuous covariates
local at _Isize_2 1 _Isize_3 0 chemo 0
foreach var of varlist age pr_1 enodes_1 {
	quietly centile `var', centile(50)
	local at `at' `var' `=r(c_1)'
}

// Predict unadjusted survival for hormon and grade
quietly stpm2 hormon, df(2) scale(odds)
predict sunh, sdiff1(hormon 1) sdiff2(hormon 0) ci
quietly stpm2 grade, df(2) scale(odds)
predict sung, sdiff1(grade 3) sdiff2(grade 2) ci

// Fit model for hormon and grade, adjusted for other variables
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)

// Predict adjusted survival for hormon at grade 3 and grade at hormon 0
predict sh, sdiff1(hormon 1 `at' grade 3) sdiff2(hormon 0 `at' grade 3) ci
predict sg, sdiff1(hormon 0 `at' grade 3) sdiff2(hormon 0 `at' grade 2) ci

// Get (unadjusted) differences in Kaplan-Meier curves
stsurvdiff hormon, generate(kmh)
stsurvdiff grade, generate(kmg)

// Plot results
gen tt = round(_t, 0.05)
quietly bysort tt : drop if _n > 1
global stuff xtitle("") ytitle("") sort legend(off) ///
 lpattern(l l l - ..) ylabel(, angle(h) format(%4.1f))
line sung sung_* kmg kmg_lci kmg_uci tt, $stuff ///
 title("Grade (unadjusted)") name(g1, replace)
line sg sg_* tt, $stuff title("Grade (adjusted)") name(g2, replace)
line sunh sunh_* kmh kmh_lci kmh_uci tt, $stuff ///
 title("Hormon (unadjusted)") name(g3, replace)
line sh sh_* tt, $stuff title("Hormon (adjusted)") name(g4, replace)
graph combine g1 g2 g3 g4, ycommon xcommon b2title("Years since surgery") ///
 l1title("Difference in S(t)")
set more on
