/*
	Chapter 7. 
	Building a time-varying proportional odds model for
	the Rotterdam data.
	Includes figure 7.27
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit final model (dftvc = 2 for pr_1, 1 for chemo)
quietly xi:stpm2 age enodes_1 pr_1 i.size i.grade chemo hormon, df(2) sc(o) tvc(pr_1 chemo) dftvc(pr_1:2 chemo:1)

// Predict HR and ci for each TV variable.
// For pr, compare HR between median and minimum values.
quietly sum pr_1, detail
local min = r(min)
local median = r(p50)
predict hrpr, hrnum(pr_1 `median') hrden(pr_1 `min') ci
predict hrchemo, hrnum(chemo 1) ci

// Figure 7.27
// Plot HRs against time
preserve
quietly bysort _t: keep if _n == 1
twoway (rarea hrpr_lci hrpr_uci _t, sort pstyle(ci)) ///
 (line hrpr _t, sort lstyle(refline)), yline(1) ///
 title("log(pr + 1)") xtitle("") ytitle("") name(g1, replace) legend(off)
twoway (rarea hrchemo_lci hrchemo_uci _t, sort pstyle(ci)) ///
 (line hrchemo _t, sort lstyle(refline)), yline(1) ///
 title("chemo") xtitle("") ytitle("") name(g2, replace) legend(off)
graph combine g1 g2, l1title("Hazard ratio") ///
 b2title("Years from surgery") ycommon
restore
set more on
