/*
	Chapter 9
	Figure 9.9
	CD4 data. 94% reference intervals by Royston & Wright
	method and stpm2 Probit(2) outcome-dependent model.
*/
version 11.0
set scheme sj
set more off
clear
use cd4

stset cd4
stpm2 x_1 x_2, scale(normal) df(2) dftvc(2) tvc(x_1 x_2) nolog

// Compute reference centiles
predict c3, centile(3)
replace c3 = ln(c3)
predict c97, centile(97)
replace c97 = ln(c97)

// Royston & Wright (1998) method
xriml y x, fp(m:0.5 3, g:1) dist(en) nograph

// Plot results
twoway (scatter y age, ms(oh) mcolor(gs10)) ///
 (line c3 c97 C3 C97 age, sort lpattern(l l - -) lwidth(medthick ..)), ///
 legend(label(2 "3rd centile, RP") label(3 "97th centile, RP") ///
 label(4 "3rd centile, RW") label(5 "97th centile, RW") ///
 ring(0) pos(1) col(1) order(2 3 4 5)) ///
 xtitle("Age, days") ytitle("Log CD4 count") ylab(,angle(h)) ///
 name(g1, replace)
set more on
