/*
	Renal data
	Average survival curves
	Includes figures 9.2, 9.3, 9.4, 9.5
*/
version 11.0
set more off
clear
use renal

label define asian 0 "Non-South Asian" 1 "South Asian"
rename asian s_asian
label values s_asian asian

stset stime, failure(dead == 1)  id(id) scale(365.25) exit(time 5*365.25)

sts gen s_km = s, by(s_asian)

// Figure 9.2
twoway	(line s_km _t if s_asian == 0, sort lpattern(solid) lwidth(medthick) lcolor(black) connect(stairstep)) ///
		(line s_km _t if s_asian == 1, sort lpattern(solid) lwidth(medthick) lcolor(gs8) connect(stairstep)) ///
		, legend(order(1 "Non-South Asian" 2 "South Asian") ring(0) pos(7) col(1) size(*1)) scheme(sj) ///
		xtitle("Survival Time (years)",) ytitle("Survival function",) ///
		 ylabel(0(0.2)1.0,angle(h) format(%3.1f)) ///
		name(km1, replace)

stpm2 s_asian, df(3) scale(hazard)  eform nolog

table s_asian, c(n age mean age sd age) format(%9.2f)

stpm2 s_asian age, df(3) scale(hazard)  eform nolog

summ age, meanonly
local mean_age = `r(mean)'
predict s0_meancov, survival at(s_asian 0 age `mean_age')
predict s1_meancov, survival at(s_asian 1 age `mean_age')

// Figure 9.3
twoway	(line s_km _t if s_asian == 0, sort lpattern(shortdash) lwidth(thin) lcolor(black) connect(stairstep)) ///
		(line s_km _t if s_asian == 1, sort lpattern(shortdash) lwidth(thin) lcolor(gs8) connect(stairstep)) ///
		(line s0_meancov _t, sort lpattern(solid) lwidth(medthick) lcolor(black)) ///
		(line s1_meancov _t, sort lpattern(solid) lwidth(medthick) lcolor(gs8)) ///
		, legend(order(3 "Non-South Asian" 4 "South Asian") ring(0) pos(7) col(1) size(*1)) scheme(sj) ///
		xtitle("Survival time (years)",) ytitle("Survival function",) ///
		 ylabel(0(0.2)1.0,angle(h) format(%3.1f)) ///
		name(km_meancov, replace)

/* Age distribution for study population as a whole */
predict s0_diradj_all, meansurv at(s_asian 0)
predict s1_diradj_all, meansurv at(s_asian 1)

// Figure 9.4
twoway	(line s_km _t if s_asian == 0, sort lpattern(shortdash) lwidth(thin) lcolor(black) connect(stairstep)) ///
		(line s_km _t if s_asian == 1, sort lpattern(shortdash) lwidth(thin) lcolor(gs8) connect(stairstep)) ///
		(line s0_diradj_all _t, sort lpattern(solid) lwidth(medthick) lcolor(black)) ///
		(line s1_diradj_all _t, sort lpattern(solid) lwidth(medthick) lcolor(gs8)) ///
		, legend(order(3 "Non-South Asian" 4 "South Asian") ring(0) pos(7) col(1) size(*1)) scheme(sj) ///
		xtitle("Survival Time (years)",) ytitle("Survival Function",) ///
		 ylabel(0(0.2)1.0,angle(h) format(%3.1f)) ///
		name(km_diradj_all, replace)

/* Age distribution for non south asians */
predict s0_diradj_nonasian if s_asian == 0, meansurv at(s_asian 0)
predict s1_diradj_nonasian if s_asian == 0, meansurv at(s_asian 1)

/* Age distribution for south asians */
predict s0_diradj_asian if s_asian == 1, meansurv at(s_asian 0)
predict s1_diradj_asian if s_asian == 1, meansurv at(s_asian 1)

// Figure 9.5
twoway	(line s_km _t if s_asian == 0, sort lpattern(shortdash) lwidth(thin) lcolor(black) connect(stairstep)) ///
		(line s_km _t if s_asian == 1, sort lpattern(shortdash) lwidth(thin) lcolor(gs8) connect(stairstep)) ///
		(line s0_diradj_nonasian _t, sort lpattern(solid) lwidth(medthick) lcolor(black)) ///
		(line s1_diradj_nonasian _t, sort lpattern(solid) lwidth(medthick) lcolor(gs8)) ///
		, legend(order(3 "Non-South Asian" 4 "South Asian") ring(0) pos(7) col(1) size(*1)) scheme(sj) ///
		xtitle("Survival Time (years)",) ytitle("Survival Function",) ///
		 ylabel(0(0.2)1.0,angle(h) format(%3.1f)) ///
		name(km_diradj_nonasian, replace)
twoway	(line s_km _t if s_asian == 0, sort lpattern(shortdash) lwidth(thin) lcolor(black) connect(stairstep)) ///
		(line s_km _t if s_asian == 1, sort lpattern(shortdash) lwidth(thin) lcolor(gs8) connect(stairstep)) ///
		(line s0_diradj_asian _t, sort lpattern(solid) lwidth(medthick) lcolor(black)) ///
		(line s1_diradj_asian _t, sort lpattern(solid) lwidth(medthick) lcolor(gs8)) ///
		, legend(order(3 "Non-South Asian" 4 "South Asian") ring(0) pos(7) col(1) size(*1)) scheme(sj) ///
		xtitle("Survival Time (years)",) ytitle("Survival Function",) ///
		 ylabel(0(0.2)1.0,angle(h) format(%3.1f)) ///
		name(km_diradj_asian, replace)
graph combine km_diradj_nonasian km_diradj_asian, nocopies 

forvalues i = 1/3 {
	summ _rcs`i' if _t == 5, meanonly
	local c`i' `r(mean)'
}
margins, at(_rcs1 = `c1' _rcs2 =`c2' _rcs3 =`c3' s_asian=(0 1)) ///
	expression(predict(survival)) post
 			
lincom _b[1._at] - _b[2._at]
set more on
